# Contributing

Thanks for wanting to contribute to this project! ❤️

## Python package and project manager

scan2any uses [uv](https://github.com/astral-sh/uv) as Python package and
project manager.

## Code Guidelines

Before each commit, please run `ruff format` and `ruff check`. You can use
pre-commit hook in `data` by copying it into the git hook folder
(`cp data/pre-commit .git/hooks`). Or simply use 
[pre-commit](https://pre-commit.com/) `pre-commit install`.
